@@ -12,12 +12,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 SUPPORTED_CDI_VERSIONS = ["2.9", "2.10", "2.11", "2.12", "2.13", "2.14", "2.15"]
-VERSION = "0.11.4"
+VERSION = "0.11.7"
 TELEMETRY = "/telemetry"
 USER_COUNT = "/users/count"
 USER_DELETE = "/user/remove"
 USERS = "/users"
-TELEMETRY_SUPERTOKENS_API_URL = "https://api.supertokens.io/0/st/telemetry"
+TELEMETRY_SUPERTOKENS_API_URL = "https://api.supertokens.com/0/st/telemetry"
 TELEMETRY_SUPERTOKENS_API_VERSION = "2"
 ERROR_MESSAGE_KEY = "message"
 API_KEY_HEADER = "api-key"
