@@ -16,15 +16,11 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Callable, Union
 
-from supertokens_python.ingredients.emaildelivery.types import EmailDeliveryConfig
 
 from . import exceptions as ex
 from . import providers, utils
-from .emaildelivery import services as emaildelivery_services
 from .recipe import ThirdPartyRecipe
-from .types import EmailTemplateVars
 
-InputEmailVerificationConfig = utils.InputEmailVerificationConfig
 InputOverrideConfig = utils.InputOverrideConfig
 SignInAndUpFeature = utils.SignInAndUpFeature
 Apple = providers.Apple
@@ -34,7 +30,6 @@ Github = providers.Github
 Google = providers.Google
 GoogleWorkspaces = providers.GoogleWorkspaces
 exceptions = ex
-SMTPService = emaildelivery_services.SMTPService
 
 if TYPE_CHECKING:
     from supertokens_python.supertokens import AppInfo
@@ -44,10 +39,6 @@ if TYPE_CHECKING:
 
 def init(
     sign_in_and_up_feature: SignInAndUpFeature,
-    email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
     override: Union[InputOverrideConfig, None] = None,
-    email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
 ) -> Callable[[AppInfo], RecipeModule]:
-    return ThirdPartyRecipe.init(
-        sign_in_and_up_feature, email_verification_feature, override, email_delivery
-    )
+    return ThirdPartyRecipe.init(sign_in_and_up_feature, override)
