@@ -28,7 +28,6 @@ from .recipe import ThirdPartyPasswordlessRecipe
 from .smsdelivery import services as smsdelivery_services
 from .types import EmailTemplateVars, SMSTemplateVars
 
-InputEmailVerificationConfig = utils.InputEmailVerificationConfig
 InputOverrideConfig = utils.InputOverrideConfig
 exceptions = ex
 ContactConfig = passwordless.ContactConfig
@@ -57,13 +56,9 @@ def init(
     flow_type: Literal[
         "USER_INPUT_CODE", "MAGIC_LINK", "USER_INPUT_CODE_AND_MAGIC_LINK"
     ],
-    get_link_domain_and_path: Union[
-        Callable[[PhoneOrEmailInput, Dict[str, Any]], Awaitable[str]], None
-    ] = None,
     get_custom_user_input_code: Union[
         Callable[[Dict[str, Any]], Awaitable[str]], None
     ] = None,
-    email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
     email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
     sms_delivery: Union[SMSDeliveryConfig[SMSTemplateVars], None] = None,
     override: Union[InputOverrideConfig, None] = None,
@@ -72,9 +67,7 @@ def init(
     return ThirdPartyPasswordlessRecipe.init(
         contact_config,
         flow_type,
-        get_link_domain_and_path,
         get_custom_user_input_code,
-        email_verification_feature,
         email_delivery,
         sms_delivery,
         override,
